@@ -5,7 +5,7 @@ import core.models
 
 class Cliente(core.models.Log, core.models.PessoaLog):
     cpf = models.BigIntegerField(primary_key=True)
-    imagem = models.FileField(upload_to='fotos/clientes', default='fotos/no-photo.png', null=True)
+    imagem = models.FileField(upload_to='fotos/clientes', default='fotos/sem-foto.png', null=True)
 
     origem_codigo = models.CharField(null=True, max_length=200)
     origem_tipo = models.CharField(null=True, max_length=200, default='CLIENTE.ORIGEM')
